Documentation
¶
Overview ¶
Package cmd provides the command line interface. Build variables are set via ldflags during build time.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CLI ¶
type CLI struct {
// contains filtered or unexported fields
}
CLI holds the command line interface state.
type ProjectNotFoundError ¶
type ProjectNotFoundError struct {
Path string
}
ProjectNotFoundError is returned when the Claude project directory does not exist.
func (*ProjectNotFoundError) Error ¶
func (e *ProjectNotFoundError) Error() string
Click to show internal directories.
Click to hide internal directories.